@@ -1,14 +1,24 @@
-# -*- coding: latin-1 -*-
+# -*- coding: utf-8 -*-
 
 import gtk
+import os
+from gettext import gettext as _
 
 Authors = ["Christian Schaller <uraeus@gnome.org>",
            "Łukasz Jernaś <deejay1@srem.org>",
            "Nicolò Chieffo <nicolo.chieffo@gmail.com>",
-           "Steven Walter <stevenrwalter@gmail.com>"]
-
-Translators = ("Łukasz Jernaś <deejay1@srem.org>")
+           "Steven Walter <stevenrwalter@gmail.com>",
+           "Michal Schmidt <mschmidt@redhat.com>",
+           "Stephane Maniaci <stephane.maniaci@gmail.com>",
+           "Jordi Mas <jmas@softcatala.org>",
+           "Stuart Langridge <sil@kryogenix.org>",
+           "Tom Parker <palfrey@tevp.neta>",
+           "Arun Raghavan <arunsr@gnome.org>",
+           "Laszlo Pandy <laszlok2@gmail.com>",
+           "Claude Paroz <claude@2xlibre.net>"
+           ]
 
+Artists = ["Emily and Liam <liam@fightingcrane.com>"]
 LGPL = """
 Transmageddon
 Copyright (C) 2009 Transmageddon Authors
@@ -32,10 +42,12 @@ Boston, MA 02111-1307, USA.
 class AboutDialog:
    def __init__(self):
        x = gtk.AboutDialog()
-       x.set_version("0.9")
+       x.set_version("0.20")
        x.set_name("Transmageddon")
        x.set_authors(Authors)
-       x.set_translator_credits(Translators)
+       x.set_translator_credits(_("translator-credits"))
+       x.set_artists(Artists)
+       x.set_logo_icon_name("transmageddon")
        x.set_license(LGPL)   
        x.connect("response", lambda d, r: d.destroy())
        x.show()
